<?php

namespace Drupal\domain_group_alias\Form;

use Drupal\Core\Form\FormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Drupal\domain_group_alias\Plugin\DomainGroupAliasSettingsManager;
use Drupal\group\Entity\GroupInterface;

/**
 * Class DomainGroupAliasSettingsForm.
 */
class DomainGroupAliasSettingsForm extends FormBase {

  /**
   * The DomainGroupAliasSettingsManager service.
   *
   * @var \Drupal\domain_group_alias\Plugin\DomainGroupAliasSettingsManager
   */
  protected $pluginManagerDomainGroupAliasSettings;

  /**
   * Constructs a new DomainGroupSettingsForm object.
   */
  public function __construct(DomainGroupAliasSettingsManager $pluginManagerDomainGroupAliasSettings) {
    $this->pluginManagerDomainGroupAliasSettings = $pluginManagerDomainGroupAliasSettings;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('plugin.manager.domain_group_alias_settings')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'domain_group_alias_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state, GroupInterface $group = NULL) {
    foreach ($this->pluginManagerDomainGroupAliasSettings->getAll() as $plugin_id => $plugin) {
      $form[$plugin_id] = [
        '#type' => 'details',
        '#title' => $plugin->getLabel(),
      ] + $plugin->buildConfigurationForm($form, $form_state, $group);
    }
    // Open only main options.
    $form['domain_group_alias_site_settings']['#open'] = TRUE;
    $form['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Submit'),
    ];

    return $form;
  }

  /**
   * {@inheritdoc}
   */
  public function validateForm(array &$form, FormStateInterface $form_state) {
    foreach ($this->pluginManagerDomainGroupSettings->getAll() as $plugin) {
      $plugin->validateConfigurationForm($form, $form_state);
    }
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    foreach ($this->pluginManagerDomainGroupSettings->getAll() as $plugin) {
      $plugin->submitConfigurationForm($form, $form_state);
    }
    $this->messenger()->addStatus('Changes saved');
  }

}
